﻿
using CSHTML5;
using System;
using System.Threading.Tasks;
using Windows.UI.Xaml;

public static class ReactScriptsHelper
{
    static bool Initialized;

    public static async Task InitializeReact()
    {
        if (!Initialized)
        {
            // Ensure that the React and Babel-standalone libraries have been loaded:
            await Interop.LoadJavaScriptFile(@"https://unpkg.com/react@16/umd/react.production.min.js");
            await Interop.LoadJavaScriptFile(@"https://unpkg.com/react-dom@16/umd/react-dom.production.min.js");
            await Interop.LoadJavaScriptFile(@"https://unpkg.com/babel-standalone@6.15.0/babel.min.js");
            Initialized = true;
        }
    }

    public static void LoadReactScript(string url)
    {
        if (Initialized)
        {
            if (!Interop.IsRunningInTheSimulator)
            {
                AddReactScriptToHeadAndTranspile(url);
            }
            else
            {
                MessageBox.Show(@"To use React, please wait for the compilation to complete, then check the option 'Use http://localhost', and click 'Run in browser'.");
            }
        }
        else
        {
            throw new Exception("Please call the 'ReactScriptsHelper.InitializeReact()' method before calling this method.");
        }
    }

    static void AddReactScriptToHeadAndTranspile(string url)
    {
        string html5Path = CSHTML5.Native.Html.UriHelper.ConvertToHtmlPath(url);

        Interop.ExecuteJavaScript(
@"
    // Add the script tag to the head
    var head = document.getElementsByTagName('head')[0];
    var script = document.createElement('script');
    script.type = 'text/babel';
    script.src = $0;
    head.appendChild(script);

    // Raise the 'DOMContentLoaded' event so that Babel-Standalone can transpile the React script into plain JavaScript:
    window.dispatchEvent(new Event('DOMContentLoaded'));

", html5Path);
    }
}